pub struct ApiVersionManager {
CurrentVersion: ApiVersion,
CompatibleVersions: Vec<ApiVersion>,
}Expand description
Tracks the current host API version and a set of compatible peer versions.
Fields
CurrentVersion: ApiVersionCompatibleVersions: Vec<ApiVersion>Implementations
Sourceimpl ApiVersionManager
impl ApiVersionManager
pub fn new() -> Self
pub fn current(&self) -> &ApiVersion
pub fn IsCompatible(&self, version: &ApiVersion) -> bool
Sourcepub fn register_compatible(&mut self, version: ApiVersion)
pub fn register_compatible(&mut self, version: ApiVersion)
Register version as compatible if it passes the compatibility check.